==> language-env_0.66.tar.gz: language-env-0.63/ja/dot.bashrc.pl <==
# s comment -*-coding: euc-jp;-*-
bash GA KIDOU SURU TOKI NI JIKKOU SAREMASU.
SAMAZAMA NA SETTEI WO SHITEIRU NODE, MEWO TOOSHITE OITE KUDASAI.
END
bash ưȤ˼¹Ԥޤ
ޤޤ򤷤ƤΤǡܤ̤ƤƤ
END
print <<'EOF';
# 󥷥ǤϤʤ bash εư˼¹Ԥ롣
# ----- Ū -----
EOF


print "# XIM С̾\n";
print "# (XIM ϡlanguage-env ǻȤѿǤ)\n";
if ($IM_DEFAULT eq "Canna") {
	print "XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "XIM=skkinput\n";
} 
if ($IM_HOST{"Canna"} ne "") {
	print "CANNAHOST=$IM_HOST{'Canna'}\nexport CANNAHOST\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "JSERVER=$IM_HOST{'Wnn'}\nexport JSERVER\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "SKKSERVER=$IM_HOST{'SKK'}\nexport SKKSERVER\n";
}


print <<'EOF';
# xprop ϡxbase-clients ѥå˴ޤޤޤ
if [ -n "$WINDOWID" -a -x /usr/bin/X11/xprop ] ; then
  # X Window System äƤ뤱 X Window System ̿븢¤
  # ʤȤ (su Ȥʤ) ؤк
  xprop -id $WINDOWID >& /dev/null || unset WINDOWID
fi
if [ -n "$WINDOWID" -a -x /usr/bin/X11/xprop ] ; then
  XPROP=`xprop -id $WINDOWID WM_CLASS`
  case $XPROP in
  *kterm* | *krxvt* | *kwterm* | *katerm* ) LANG=ja_JP.EUC-JP ;;
  *UXTerm* ) LANG=ja_JP.UTF-8 ;;
  *hanterm* ) LANG=ko_KR.eucKR ;;
  *caterm* | *crxvt-big5* ) LANG=zh_TW.Big5 ;;
  *crxvt-gb* ) LANG=zh_CN.GB2312 ;;
  *aterm* ) LANG=C ;;
  # gnome-terminal  $WINDOWID ΰ̣㤦
  # mlterm  WM_CLASS ꤷʤ
  # Eterm 뼫ưǧˤʤä
  # xterm 뼫ưǧˤʤä (ե꤬ɬ)
  # rxvt-beta 뼫ưǧ
  * ) : ;;
  esac
else
  case $TERM in
    linux) LANG=C ;;
    xterm)
      if [ "$COLORTERM" != "gnome-terminal" ] ; then
        LANG=C
      fi ;;
    jfbterm) : ;;
    *) LANG=ja_JP.EUC-JP ;;
  esac
fi
case $LANG in
  ja_JP.UTF-8) JLESSCHARSET=utf-8 ; LV=-Ou8 ;;
  ja_JP.*) JLESSCHARSET=japanese-euc ; LV=-Oej ;;
  *) JLESSCHARSET=latin1 ; LV=-Al1 ;;
esac
export LANG JLESSCHARSET LV
if type lv &>/dev/null ; then
  PAGER=lv
elif type jless &>/dev/null ; then
  PAGER=jless
elif type less &>/dev/null ; then
  PAGER=less
else
  PAGER=more
fi
export PAGER
# XMODIFIERS  export ʤΤϡemacs  Segmentation Fault 򵯤
# ˡȡDebian ˥塼ƥफεưˤбǤʤ
function rxvt {
  if /usr/bin/which krxvt &> /dev/null
  then
    krxvt $*
  else
    /usr/bin/rxvt $*
  fi
}
alias jfbterm='LANG=ja_JP.EUC-JP /usr/bin/jfbterm'
alias xemacs='XMODIFIERS= xemacs'
# perl ˤ󤹤˥󥰤ФͭˤƤ
# PERL_BADLANG=0 ; export PERL_BADLANG
# .bash_profile ǻȤ
BASHRC_DONE=1
# mh 󥹥ȡ뤵Ƥ顢PATH ˲ä롣
if [ -x /usr/bin/mh/mhmail ]
then
  if type mhmail &>/dev/null
  then
    true
  else
    PATH=$PATH:/usr/bin/mh
  fi
fi
EOF

if (!$EXTENDED) {return;}
print <<'EOF';
## ----- ߤ˱ -----
# ls ư (°ɽĤ)man ls 
if [ "$TERM" = "dumb" -o "$TERM" = "emacs" ]
then
  alias ls='/bin/ls -F'
else
  alias ls='/bin/ls -F --color=auto'
fi
# ɸ२ǥ vi ˤ롣Debian Policy Manual 
EDITOR=vi
export EDITOR
# ץץȡman bash 
if [ "$TERM" = "dumb" -o "$TERM" = "emacs" ]
then
  PS1='\w\$ '
else
  if [ "$UID" = "0" ]
  then
    PS1='\[\e[41m\]\w\$\[\e[m\] '
  else
    PS1='\[\e[7m\]\w\$\[\e[m\] '
  fi
fi
# եȤɤ°Ǻ뤫man umask 
umask 022
# less ưman less 
LESS=-M
export LESS
if type /usr/bin/lesspipe &>/dev/null
then
  LESSOPEN="| /usr/bin/lesspipe '%s'"
  LESSCLOSE="/usr/bin/lesspipe '%s' '%s'"
  export LESSOPEN LESSCLOSE
fi
# Ctrl-D ǥȤΤ롣man bash 
IGNOREEOF=3
# ȥǥ쥯ȥΥХååץեɽ
# (ݤ "chkbackups | xargs rm" ¹ԤΤ)
alias chkbackups='/usr/bin/find . -name "?*~" -o -name "?*.bak" -o -name ".[^.]?*~" -o -name ".[^.]?*.bak" -maxdepth 1'
# X Window System Ǥ
if [ "$DISPLAY" ]
then
  # ̥ѹ COLUMNS, LINES ѹ롣man bash 
  shopt -s checkwinsize
  # üɥΥȥѹ
  function xtitle()
  {
    /bin/echo -e "\033]0;$*\007\c"
  }
fi
EOF

==> language-env_0.69.tar.gz: language-env-0.69/ja/dot.bashrc.pl <==
# s comment -*-coding: euc-jp;-*-
bash GA KIDOU SURU TOKI NI JIKKOU SAREMASU.
SAMAZAMA NA SETTEI WO SHITEIRU NODE, MEWO TOOSHITE OITE KUDASAI.
END
bash ưȤ˼¹Ԥޤ
ޤޤ򤷤ƤΤǡܤ̤ƤƤ
END
print <<'EOF';
# 󥷥ǤϤʤ bash εư˼¹Ԥ롣
# ----- Ū -----
EOF


print "# XIM С̾\n";
print "# (XIM ϡlanguage-env ǻȤѿǤ)\n";
if ($IM_DEFAULT eq "Canna") {
	print "XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "Wnn") {
	print "XIM=kinput2\n";
} elsif ($IM_DEFAULT eq "SKK") {
	print "XIM=skkinput\n";
} 
if ($IM_HOST{"Canna"} ne "") {
	print "CANNAHOST=$IM_HOST{'Canna'}\nexport CANNAHOST\n";
}
if ($IM_HOST{"Wnn"} ne "") {
	print "JSERVER=$IM_HOST{'Wnn'}\nexport JSERVER\n";
}
if ($IM_HOST{"SKK"} ne "") {
	print "SKKSERVER=$IM_HOST{'SKK'}\nexport SKKSERVER\n";
}


print <<'EOF';
# xprop ϡxbase-clients ѥå˴ޤޤޤ
if [ -n "$WINDOWID" -a -x /usr/bin/X11/xprop ] ; then
  # X Window System äƤ뤱 X Window System ̿븢¤
  # ʤȤ (su Ȥʤ) ؤк
  xprop -id $WINDOWID >& /dev/null || unset WINDOWID
fi
if [ -n "$WINDOWID" -a -x /usr/bin/X11/xprop ] ; then
  XPROP=`xprop -id $WINDOWID WM_CLASS`
  case $XPROP in
  *kterm* | *krxvt* | *kwterm* | *katerm* ) LANG=ja_JP.EUC-JP ;;
  *UXTerm* ) LANG=ja_JP.UTF-8 ;;
  *hanterm* ) LANG=ko_KR.eucKR ;;
  *caterm* | *crxvt-big5* ) LANG=zh_TW.Big5 ;;
  *crxvt-gb* ) LANG=zh_CN.GB2312 ;;
  *aterm* ) LANG=C ;;
  # gnome-terminal  $WINDOWID ΰ̣㤦
  # mlterm  WM_CLASS ꤷʤ
  # Eterm 뼫ưǧˤʤä
  # xterm 뼫ưǧˤʤä (ե꤬ɬ)
  # rxvt-beta 뼫ưǧ
  * ) : ;;
  esac
else
  case $TERM in
    linux) LANG=C ;;
    xterm)
      if [ "$COLORTERM" != "gnome-terminal" ] ; then
        LANG=C
      fi ;;
    jfbterm) : ;;
    *) LANG=ja_JP.EUC-JP ;;
  esac
fi
case $LANG in
  ja_JP.UTF-8) JLESSCHARSET=utf-8 ; LV="-Ou8 -c" ;;
  ja_JP.*) JLESSCHARSET=japanese-euc ; LV="-Oej -c" ;;
  *) JLESSCHARSET=latin1 ; LV="-Al1 -c" ;;
esac
export LANG JLESSCHARSET LV
if type lv &>/dev/null ; then
  PAGER=lv
elif type jless &>/dev/null ; then
  PAGER=jless
elif type less &>/dev/null ; then
  PAGER=less
else
  PAGER=more
fi
export PAGER
# XMODIFIERS  export ʤΤϡemacs  Segmentation Fault 򵯤
# ˡȡDebian ˥塼ƥफεưˤбǤʤ
function rxvt {
  if /usr/bin/which krxvt &> /dev/null
  then
    krxvt $*
  else
    /usr/bin/rxvt $*
  fi
}
alias jfbterm='LANG=ja_JP.EUC-JP /usr/bin/jfbterm'
alias xemacs='XMODIFIERS= xemacs'
# perl ˤ󤹤˥󥰤ФͭˤƤ
# PERL_BADLANG=0 ; export PERL_BADLANG
# .bash_profile ǻȤ
BASHRC_DONE=1
# mh 󥹥ȡ뤵Ƥ顢PATH ˲ä롣
if [ -x /usr/bin/mh/mhmail ]
then
  if type mhmail &>/dev/null
  then
    true
  else
    PATH=$PATH:/usr/bin/mh
  fi
fi
EOF

if (!$EXTENDED) {return;}
print <<'EOF';
## ----- ߤ˱ -----
# ls ư (°ɽĤ)man ls 
if [ "$TERM" = "dumb" -o "$TERM" = "emacs" ]
then
  alias ls='/bin/ls -F'
else
  alias ls='/bin/ls -F --color=auto'
fi
# ɸ२ǥ vi ˤ롣Debian Policy Manual 
EDITOR=vi
export EDITOR
# ץץȡman bash 
if [ "$TERM" = "dumb" -o "$TERM" = "emacs" ]
then
  PS1='\w\$ '
else
  if [ "$UID" = "0" ]
  then
    PS1='\[\e[41m\]\w\$\[\e[m\] '
  else
    PS1='\[\e[7m\]\w\$\[\e[m\] '
  fi
fi
# եȤɤ°Ǻ뤫man umask 
umask 022
# less ưman less 
LESS=-M
export LESS
if type /usr/bin/lesspipe &>/dev/null
then
  LESSOPEN="| /usr/bin/lesspipe '%s'"
  LESSCLOSE="/usr/bin/lesspipe '%s' '%s'"
  export LESSOPEN LESSCLOSE
fi
# Ctrl-D ǥȤΤ롣man bash 
IGNOREEOF=3
# ȥǥ쥯ȥΥХååץեɽ
# (ݤ "chkbackups | xargs rm" ¹ԤΤ)
alias chkbackups='/usr/bin/find . -name "?*~" -o -name "?*.bak" -o -name ".[^.]?*~" -o -name ".[^.]?*.bak" -maxdepth 1'
# X Window System Ǥ
if [ "$DISPLAY" ]
then
  # ̥ѹ COLUMNS, LINES ѹ롣man bash 
  shopt -s checkwinsize
  # üɥΥȥѹ
  function xtitle()
  {
    /bin/echo -e "\033]0;$*\007\c"
  }
fi
EOF
